diff --git a/data-src/appversion b/data-src/appversion
index e4a0720..d003324 100644
--- a/data-src/appversion
+++ b/data-src/appversion
@@ -1 +1 @@
-3.0.11
\ No newline at end of file
+3.0.12
\ No newline at end of file
diff --git a/data-src/index.html b/data-src/index.html
index e64b0e6..e49d1c0 100644
--- a/data-src/index.html
+++ b/data-src/index.html
@@ -8,9 +8,9 @@
-
-
-
+
+
+
@@ -114,7 +114,7 @@
rel="apple-touch-startup-image">
-
+
diff --git a/src/ConfigSettings.h b/src/ConfigSettings.h
index 72c7127..67bd9c9 100644
--- a/src/ConfigSettings.h
+++ b/src/ConfigSettings.h
@@ -7,7 +7,7 @@
#include "WResp.h"
#ifndef FW_VERSION
- #define FW_VERSION "v3.0.11" // Fallback if app_version.py script fails
+ #define FW_VERSION "v3.0.12" // Fallback if app_version.py script fails
#endif
enum class conn_types_t : byte {
diff --git a/data-src/index.js b/data-src/index.js
index 69dcb70..b4a9ffe 100644
--- a/data-src/index.js
+++ b/data-src/index.js
@@ -1271,7 +1271,7 @@ class Security {
}
var security = new Security();
// let appVersion = 'v3.0.11'; // Default placeholder
async function getAppVersion() {
try {
const response = await fetch('/appversion');
@@ -1284,7 +1284,7 @@ async function getAppVersion() {
// Trigger any UI updates here
} catch (error) {
console.error("Error loading App version:", error);
- appVersion = 'v3.0.11'; // Default placeholder
+ appVersion = 'v3.0.12'; // Default placeholder
}
return appVersion;
}
@@ -1271,7 +1271,7 @@ class Security {
}
var security = new Security();
-// let appVersion = 'v3.0.11'; // Default placeholder
+// let appVersion = 'v3.0.12'; // Default placeholder
async function getAppVersion() {
try {